@@ -31,6 +31,8 @@ class VaspErrorHandlerTest(unittest.TestCase):
         if "VASP_PSP_DIR" not in os.environ:
             os.environ["VASP_PSP_DIR"] = test_dir
         os.chdir(test_dir)
+        shutil.copy("INCAR", "INCAR.orig")
+        shutil.copy("KPOINTS", "KPOINTS.orig")
         h = VaspErrorHandler("vasp.teterror")
         h.check()
         d = h.correct()
@@ -43,12 +45,21 @@ class VaspErrorHandlerTest(unittest.TestCase):
         d = h.correct()
         self.assertEqual(d["errors"], ['mesh_symmetry'])
         self.assertEqual(d["actions"],
-                         [{'action': {'_set': {'kpoints': [[8, 8, 8]]}},
+                         [{'action': {'_set': {'kpoints': [[4, 4, 4]]}},
                            'dict': 'KPOINTS'}])
+        shutil.move("INCAR.orig", "INCAR")
+        shutil.move("KPOINTS.orig", "KPOINTS")
         os.remove(os.path.join(test_dir, "error.1.tar.gz"))
         os.remove(os.path.join(test_dir, "error.2.tar.gz"))
 
 
+    def test_to_from_dict(self):
+        h = VaspErrorHandler("random_name")
+        h2 = VaspErrorHandler.from_dict(h.to_dict)
+        self.assertEqual(type(h2), type(h))
+        self.assertEqual(h2.output_filename, "random_name")
+
+
 class UnconvergedErrorHandlerTest(unittest.TestCase):
 
     def test_check_correct(self):
@@ -67,6 +78,12 @@ class UnconvergedErrorHandlerTest(unittest.TestCase):
                            'action': {'_set': {'ISTART': 1}}}])
         os.remove(os.path.join(subdir, "error.1.tar.gz"))
 
+    def test_to_from_dict(self):
+        h = UnconvergedErrorHandler("random_name.xml")
+        h2 = UnconvergedErrorHandler.from_dict(h.to_dict)
+        self.assertEqual(type(h2), UnconvergedErrorHandler)
+        self.assertEqual(h2.output_filename, "random_name.xml")
+
 
 class PoscarErrorHandlerTest(unittest.TestCase):
 
@@ -84,6 +101,13 @@ class PoscarErrorHandlerTest(unittest.TestCase):
         shutil.copy("POSCAR.orig", "POSCAR")
         os.remove("POSCAR.orig")
 
+    def test_to_from_dict(self):
+        h = PoscarErrorHandler("random_name.out")
+        h2 = PoscarErrorHandler.from_dict(h.to_dict)
+        self.assertEqual(type(h2), PoscarErrorHandler)
+        self.assertEqual(h2.output_filename, "random_name.out")
+
+
 if __name__ == "__main__":
     #import sys;sys.argv = ['', 'Test.testName']
     unittest.main()
